Don't cares
-----------

**Header:** ``mockturtle/algorithms/dont_cares.hpp``

.. doxygenfunction:: mockturtle::satisfiability_dont_cares
.. doxygenstruct:: mockturtle::satisfiability_dont_cares_checker
